import { csv, scaleLinear, scaleOrdinal, max, format, extent } from 'd3';
import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import ReactDropdown from 'react-dropdown';
import { config } from './config';
import { useData } from './useData';
import { AxisBottom } from './AxisBottom';
import { AxisLeft } from './AxisLeft';
import { Marks } from './Marks';
import { Dropdown } from './Dropdown';
//import { getData } from './getData';
//import { viz } from './viz';

const width = 960;
const menuHeight = 80;
const height = 500 - menuHeight;
const margin = { top: 20, right: 30, bottom: 65, left: 90 };
const xAxisLabelOffset = 50;
const yAxisLabelOffset = 45;

const attributes = [
//  { value: 'State', label: 'State' },
  { value: 'ILI_Percent', label: 'ILI Percentage' },
  { value: 'ILI_Total', label: 'ILI Total' },
  { value: 'Providers', label: 'Providers' },
  { value: 'Pat_Total', label: 'Total Patients' },
];

const getLabel = value => {
  for (let i = 0; i < attributes.length; i++) {
    if (attributes[i].value === value) {
      return attributes[i].label;
    }
  }
};

const App = () => {
  const data = useData();

  const initialXAttribute = 'Week';
  const [xAttribute, setXAttribute] = useState(initialXAttribute);
  const xValue = d => d[xAttribute];
//  const xAxisLabel = getLabel(xAttribute);
  const xAxisLabel = 'Week of the Year';

  const initialYAttribute = 'ILI_Percent';
  const [yAttribute, setYAttribute] = useState(initialYAttribute);
  const yValue = d => d[yAttribute];
  const yAxisLabel = getLabel(yAttribute);

  const colorValue = d => d.Year;
  const sizeValue = d => d.ILI_Total;
  const tooltipValue = d => d.ILI_Total;
  
  if (!data) {
    return <pre>Loading...</pre>;
  }

  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;
  const siFormat = format('.2s');
  const xAxisTickFormat = tickValue => siFormat(tickValue).replace('G', 'B');

  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();

  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0]);

  const sizeScale = scaleLinear()
    .domain(extent(data, sizeValue))
    .range([1.1, 8.8]);

  const colorScale = scaleOrdinal()
  	.domain(data.map(colorValue))
  	.range(['#2b8cbe','#fec44f','#de2d26','#31a354','#deebf7']);
//  	.range(['#2b8cbe','#fec44f','#de2d26','#756bb1','#deebf7','#31a354','#fff7bc']);
  
  //console.log(colorScale.domain());
  //console.log(colorScale.range());
  
  return (
    <>
      <div className="menus-container">
        <span className="dropdown-label">Choose a data field:</span>
        <ReactDropdown
          options={attributes}
          value={yAttribute}
          onChange={({ value }) => setYAttribute(value)}
        />
      </div>
      <svg width={width} height={height}>
        <g transform={`translate(${margin.left},${margin.top})`}>
          <AxisBottom
            xScale={xScale}
            innerHeight={innerHeight}
            tickFormat={xAxisTickFormat}
            tickOffset={5}
          />
          <text
            className="axis-label"
            textAnchor="middle"
            transform={`translate(${-yAxisLabelOffset},${innerHeight /
              2}) rotate(-90)`}
          >
            {yAxisLabel}
          </text>
          <AxisLeft yScale={yScale} innerWidth={innerWidth} tickOffset={5} />
          <text
            className="axis-label"
            x={innerWidth / 2}
            y={innerHeight + xAxisLabelOffset}
            textAnchor="middle"
          >
            {xAxisLabel}
          </text>
          <Marks
            data={data}
            xScale={xScale}
            yScale={yScale}
            xValue={xValue}
            yValue={yValue}
            clrScale={colorScale}
            clrValue={colorValue}
            sizeScale={sizeScale} 
            circleRadius={sizeValue}
            tooltipFormat={xAxisTickFormat}
            ttpValue={tooltipValue}
          />
        </g>
      </svg>
    </>
  );
};



const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
